package com.example.project.main.components

import android.os.Build
import androidx.annotation.RequiresApi
import androidx.compose.runtime.Composable
import androidx.navigation.NavHostController
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.toRoute
import com.example.greentown.View
import com.example.greentown.dataView.AdminView
import com.example.greentown.dataView.AuthView
import com.example.greentown.dataView.InfoView
import com.example.greentown.dataView.StartView
import com.example.greentown.dataView.MainView
import com.example.greentown.dataView.ProductInfoScreen
import com.example.greentown.dataView.QrCodeView
import com.example.greentown.dataView.RecView
import com.example.greentown.dataView.TypeDetails
import com.example.greentown.dataView.TypeList
import com.example.greentown.dataView.TypeListScreen
import com.example.greentown.dataView.TypeScreen
import com.example.greentown.dataView.operationView.InsertView
import io.github.jan.supabase.SupabaseClient

@RequiresApi(Build.VERSION_CODES.O)
@Composable
fun Navigation(controller: NavHostController) {
    NavHost(
        navController = controller,
        startDestination = View.StartView.route) {
        composable(View.StartView.route) {
            StartView(controller)
        }
        composable(View.MainView.route) {
            MainView(controller)
        }
        composable(View.RecView.route) {
            RecView(controller)
        }
        composable(View.InfoView.route) {
            InfoView(controller)
        }
        composable(View.AuthView.route) {
            AuthView(controller)
        }
        composable(View.AdminView.route) {
            AdminView(controller)
        }
        composable<TypeListScreen> {
            TypeList(
                onTypeClick = {
                    controller.navigate(TypeScreen(id = it))
                }
            )
        }
        composable<TypeScreen> {
            val args = it.toRoute<TypeScreen>()
            TypeDetails(controller, typeID = args.id)
        }
        composable(View.InsertView.route) {
            InsertView(controller)
        }
        composable(View.DeleteView.route) {
            InsertView(controller)
        }
        composable(View.QrCodeView.route) {
            QrCodeView(controller)
        }

    }
}