package com.example.greentown.dataView

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.offset
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.colorResource
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.text.input.VisualTransformation
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavHostController
import com.example.greentown.viewModel.MainViewModel
import com.example.greentown.R
import com.example.greentown.ui.theme.font2
import com.example.greentown.ui.theme.font3

@Composable
fun AuthView(navController: NavHostController) {
    val viewModel = MainViewModel()
    val email = remember { mutableStateOf("") }
    val password = remember { mutableStateOf("") }

    Column(modifier = Modifier.fillMaxSize(),
        horizontalAlignment = Alignment.CenterHorizontally) {

        Box(modifier = Modifier.fillMaxWidth().background(color = colorResource(R.color.green2))
            .size(height = 70.dp, width = 0.dp).offset(y = 10.dp),
            contentAlignment = Alignment.Center) {
            Text("Авторизация", fontSize = 38.sp, color = Color.White,
                fontFamily = font2, fontWeight = FontWeight(1000))
            Box(modifier = Modifier.size(width = 26.dp, height = 5.dp).offset(x = 140.dp, y = 1.dp)
                .background(color = colorResource(R.color.white))) {}
            Box(modifier = Modifier.size(width = 26.dp, height = 5.dp).offset(x = (-140).dp, y = 1.dp)
                .background(color = colorResource(R.color.white))) {}}


        Spacer(modifier = Modifier.height(200.dp))

        Box(modifier = Modifier.size(height = 260.dp, width = 350.dp)
        .border(5.dp, color = colorResource(R.color.green1), RoundedCornerShape(20.dp))
            .clip(RoundedCornerShape(20.dp))
        .background(color = colorResource(R.color.green5)),
            contentAlignment = Alignment.Center) {

        Column(modifier = Modifier) {
            OutlinedTextField(value = email.value, modifier = Modifier.size(width = 270.dp, height = 60.dp)
                .border(3.dp, color = colorResource(R.color.green1))
                .background(color = colorResource(R.color.white)),
                textStyle = TextStyle(fontSize = 28.sp),
                onValueChange = { newText -> email.value = newText })

            Spacer(modifier = Modifier.height(20.dp))
            var passwordVisibility: Boolean by remember { mutableStateOf(false) }

            OutlinedTextField(value = password.value, modifier = Modifier.size(width = 270.dp, height = 60.dp)
                .border(3.dp, color = colorResource(R.color.green1))
                .background(color = colorResource(R.color.white)),
                textStyle = TextStyle(fontSize = 28.sp),
                visualTransformation = if (passwordVisibility) VisualTransformation.None else PasswordVisualTransformation(),
                leadingIcon = {
                    IconButton(modifier = Modifier.offset(x = 10.dp), onClick = {
                        passwordVisibility = !passwordVisibility
                    }) {
                        if (passwordVisibility) {
                            Icon(modifier = Modifier.size(24.dp),
                                painter = painterResource(id = R.drawable.open),
                                contentDescription = ""
                            ) }
                        else {
                            Icon(modifier = Modifier.size(24.dp),
                                painter = painterResource(id = R.drawable.close),
                                contentDescription = "") }
                    }
                }, onValueChange = { newText -> password.value = newText }) }
            }
        Spacer(modifier = Modifier.height(50.dp))

        Button( onClick =
            { viewModel.onSignInEmailPassword(email.value,password.value, navController = navController) },
            modifier = Modifier.size(width = 190.dp, height = 70.dp)
                .border(2.dp, color = colorResource(R.color.green1), shape = RoundedCornerShape(8.dp)),
                shape = RoundedCornerShape(8.dp),
            colors = ButtonDefaults.buttonColors(containerColor = colorResource(R.color.green5))) {
            Text("Войти", fontSize = 28.sp, fontFamily = font3,
                fontWeight = FontWeight(900))
        }

        Spacer(modifier = Modifier.weight(1f))

        Box(modifier = Modifier.fillMaxWidth().background(color = colorResource(R.color.green2))
            .size(height = 70.dp, width = 0.dp)) {

            Image(
                painter = painterResource(id = R.drawable.img_1),
                contentDescription = "Custom Image Button",
                modifier = Modifier.size(50.dp).offset(x = 35.dp, y = 10.dp)
                    .clickable(onClick = {navController.navigate("MainView")}))

            Image(
                painter = painterResource(id = R.drawable.img_2),
                contentDescription = "Custom Image Button",
                modifier = Modifier.size(50.dp).offset(x = 180.dp, y = 10.dp)
                    .clickable(onClick = {navController.navigate("RecView")}))

            Image(
                painter = painterResource(id = R.drawable.img_3),
                contentDescription = "Custom Image Button",
                modifier = Modifier.size(50.dp).offset(x = 330.dp, y = 10.dp)
                    .clickable(onClick = {navController.navigate("InfoView")}))
        }
    }
}