package com.example.greentown.dataView

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.offset
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.colorResource
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.text.style.TextOverflow
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavHostController
import com.example.greentown.R
import com.example.greentown.ui.theme.font2

@Composable
fun MainView(navController: NavHostController) {
    Column(modifier = Modifier.fillMaxSize(),
        horizontalAlignment = Alignment.CenterHorizontally) {

        Box(modifier = Modifier.fillMaxWidth().background(color = colorResource(R.color.green2))
            .size(height = 70.dp, width = 0.dp).offset(y = 10.dp),
            contentAlignment = Alignment.Center) {
            Text("Главная", fontSize = 38.sp, color = Color.White,
                fontFamily = font2, fontWeight = FontWeight(1000))
            Box(modifier = Modifier.size(width = 26.dp, height = 5.dp).offset(x = 100.dp, y = 1.dp)
                .background(color = colorResource(R.color.white))) {}
            Box(modifier = Modifier.size(width = 26.dp, height = 5.dp).offset(x = (-100).dp, y = 1.dp)
                .background(color = colorResource(R.color.white))) {}}

        Spacer(modifier = Modifier.height(140.dp))

        Box(modifier = Modifier.size(height = 7.dp, width = 300.dp)
            .clip(RoundedCornerShape(90.dp))
            .border(6.dp, color = colorResource(R.color.green2))) {}

        Spacer(modifier = Modifier.height(60.dp))

        Image(
            painter = painterResource(id = R.drawable.img_4),
            contentDescription = "Custom Image Button",
            modifier = Modifier.size(170.dp)
                .clickable(onClick = {navController.navigate("QrCodeView")}))

        Spacer(modifier = Modifier.height(30.dp))

        Box(modifier = Modifier, contentAlignment = Alignment.Center) {
            ExpandableText(text = "Инструкция\n" + "1. Нажмите на иконку камеры\n"
                + "2. Наведите камеру на код\n" + "3. Дождитесь появления всплывающего окна",
                maxLines = 1) }

        Spacer(modifier = Modifier.height(60.dp))

        Box(modifier = Modifier.size(height = 7.dp, width = 300.dp)
            .clip(RoundedCornerShape(90.dp))
            .border(6.dp, color = colorResource(R.color.green2))) {}

        Spacer(modifier = Modifier.weight(1f))

        Box(modifier = Modifier.fillMaxWidth().background(color = colorResource(R.color.green2))
            .size(height = 70.dp, width = 0.dp)) {

            Image(
                painter = painterResource(id = R.drawable.img_1),
                contentDescription = "Custom Image Button",
                modifier = Modifier.size(50.dp).offset(x = 35.dp, y = 10.dp)
                    .clickable(onClick = {navController.navigate("MainView")}))

            Image(
                painter = painterResource(id = R.drawable.img_2),
                contentDescription = "Custom Image Button",
                modifier = Modifier.size(50.dp).offset(x = 180.dp, y = 10.dp)
                    .clickable(onClick = {navController.navigate("RecView")}))

            Image(
                painter = painterResource(id = R.drawable.img_3),
                contentDescription = "Custom Image Button",
                modifier = Modifier.size(50.dp).offset(x = 330.dp, y = 10.dp)
                    .clickable(onClick = {navController.navigate("InfoView")}))
        }
    }
}

// Функция для развёртывания текста
@Composable
fun ExpandableText(
    text: String,
    maxLines: Int = 4) {
    var expanded by remember { mutableStateOf(false) }

    Box(
        modifier = Modifier.clickable {
            expanded = !expanded
        }
    ) {
        Text(
            text = text, fontSize = 32.sp, fontFamily = font2, textAlign = TextAlign.Center,
            maxLines = if (expanded) Int.MAX_VALUE else maxLines,
            overflow = TextOverflow.Ellipsis
        )
    }
}