package com.example.greentown.dataView

import android.app.Activity.RESULT_OK
import androidx.activity.compose.rememberLauncherForActivityResult
import androidx.activity.result.contract.ActivityResultContracts
import androidx.compose.foundation.layout.Column
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.navigation.NavHostController
import com.google.zxing.integration.android.IntentIntegrator
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext
import org.jsoup.Jsoup
import android.Manifest
import android.content.pm.PackageManager
import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.camera.core.*
import androidx.camera.lifecycle.ProcessCameraProvider
import androidx.camera.view.PreviewView
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.viewinterop.AndroidView
import androidx.core.content.ContextCompat
import androidx.lifecycle.LifecycleOwner
import com.example.greentown.View
import com.google.mlkit.common.MlKitException
import com.google.mlkit.vision.barcode.BarcodeScanner
import com.google.mlkit.vision.barcode.BarcodeScannerOptions
import com.google.mlkit.vision.barcode.BarcodeScanning
import com.google.mlkit.vision.barcode.common.Barcode
import com.google.mlkit.vision.common.InputImage
import kotlinx.coroutines.launch

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun QrCodeView(navController: NavHostController) {
    var scannedUrl by remember { mutableStateOf("") }
    var isScanning by remember { mutableStateOf(true) }
    var title by remember { mutableStateOf("") }
    var packagingType by remember { mutableStateOf("") }

    Box(modifier = Modifier.fillMaxSize(), contentAlignment = Alignment.Center) {
        if (isScanning) {
            AndroidView(
                factory = { context ->
                    val previewView = PreviewView(context)
                    startCamera(previewView) { url ->
                        scannedUrl = url
                        isScanning = false // Остановить сканирование после успешного сканирования
                    }
                    previewView
                },
                modifier = Modifier.fillMaxSize()
            )
        } else {
            fetchProductData(scannedUrl) {
                    fetchedTitle, fetchedPackagingType ->
                title = fetchedTitle
                packagingType = fetchedPackagingType
                isScanning = false
                navController.navigate("ProductInfoScreen")
            }

            Button(onClick = { isScanning = true }) {
                Text("Сканировать снова")
            }
        }
    }
}

private fun startCamera(previewView: PreviewView, onUrlScanned: (String) -> Unit) {
    val context = previewView.context

    if (context.checkSelfPermission(Manifest.permission.CAMERA) == PackageManager.PERMISSION_GRANTED) {
        val cameraProviderFuture = ProcessCameraProvider.getInstance(context)

        cameraProviderFuture.addListener({
            val cameraProvider = cameraProviderFuture.get()

            val preview = Preview.Builder().build().also {
                it.setSurfaceProvider(previewView.surfaceProvider)
            }

            val barcodeScannerOptions = BarcodeScannerOptions.Builder()
                .setBarcodeFormats(Barcode.FORMAT_QR_CODE)
                .build()

            val scanner = BarcodeScanning.getClient(barcodeScannerOptions)

            val imageAnalysis = ImageAnalysis.Builder()
                .setBackpressureStrategy(ImageAnalysis.STRATEGY_KEEP_ONLY_LATEST)
                .build()
            imageAnalysis.setAnalyzer(ContextCompat.getMainExecutor(context), { imageProxy ->
                processImageProxy(scanner, imageProxy, onUrlScanned)
            })

            val cameraSelector = CameraSelector.DEFAULT_BACK_CAMERA

            try {
                cameraProvider.unbindAll()
                cameraProvider.bindToLifecycle(
                    context as LifecycleOwner,
                    cameraSelector,
                    preview,
                    imageAnalysis
                )
            } catch (exc: Exception) {
                // Обработка ошибок при запуске камеры
            }
        }, ContextCompat.getMainExecutor(context))
    } else {
        // Запрос разрешения на использование камеры
    }
}

@androidx.annotation.OptIn(ExperimentalGetImage::class)
private fun processImageProxy(scanner: BarcodeScanner, imageProxy: ImageProxy, onUrlScanned: (String) -> Unit) {
    val mediaImage = imageProxy.image ?: return

    val inputImage = InputImage.fromMediaImage(mediaImage, imageProxy.imageInfo.rotationDegrees)

    scanner.process(inputImage)
        .addOnSuccessListener { barcodes ->
            for (barcode in barcodes) {
                // Получаем URL из QR-кода
                barcode.rawValue?.let { url ->
                    onUrlScanned(url)
                }
            }
        }
        .addOnFailureListener { e ->
            // Обработка ошибок при сканировании
        }
        .addOnCompleteListener {
            imageProxy.close() // Закрываем ImageProxy после обработки
        }
}

private fun fetchProductData(url: String, onResult: (String, String) -> Unit) { //Парсинг товаров сайта Магнит
    // Запускаем корутину для выполнения сетевого запроса
    CoroutineScope(Dispatchers.IO).launch {
        try {
            val document = Jsoup.connect(url).get()
            val title = document.select("span.pl-text.product-details-offer__title").text()
            var packagingType = ""

            val packagingItems = document.select("div.product-details-parameters-list__item")
            for (item in packagingItems) {
                val label = item.select("span.pl-text").text()
                if (label.contains("Тип упаковки")) {
                    packagingType = item.select("div[itemprop=additionalProperty] meta[itemprop=value]").attr("content")
                    break
                }
            }

            // Возвращаем результат в основном потоке
            withContext(Dispatchers.Main) {
                onResult(title, packagingType)
            }
        } catch (e: Exception) {
            e.printStackTrace()
            withContext(Dispatchers.Main) {
                onResult("Ошибка", "Ошибка")
            }
        }
    }
}