@file:OptIn(SupabaseExperimental::class)

package com.example.greentown.dataView

import androidx.compose.foundation.Image
import androidx.compose.foundation.ScrollState
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.offset
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.CornerSize
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.focus.focusModifier
import androidx.compose.ui.geometry.CornerRadius
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.colorResource
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavHostController
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.rememberNavController
import coil.compose.AsyncImage
import com.example.greentown.Domain.Constants
import com.example.greentown.Domain.Constants.supabaseClient
import com.example.greentown.Model.Type
import com.example.greentown.R
import com.example.greentown.ui.theme.font1
import com.example.greentown.ui.theme.font2
import com.example.greentown.ui.theme.font3
import io.github.jan.supabase.annotations.SupabaseExperimental
import io.github.jan.supabase.postgrest.from
import io.github.jan.supabase.postgrest.query.Columns
import io.github.jan.supabase.realtime.Column
import io.github.jan.supabase.realtime.selectAsFlow
import kotlinx.serialization.Serializable

@Composable
fun RecView(navController: NavHostController) {
    Column(modifier = Modifier.fillMaxSize(),
        horizontalAlignment = Alignment.CenterHorizontally) {

        Box(modifier = Modifier.fillMaxWidth().background(color = colorResource(R.color.green2))
            .size(height = 70.dp, width = 0.dp).offset(y = 10.dp),
            contentAlignment = Alignment.Center) {
            Text("Рекомендации",fontSize = 38.sp, color = Color.White,
                fontFamily = font2, fontWeight = FontWeight(1000))
            Box(modifier = Modifier.size(width = 26.dp, height = 5.dp).offset(x = (-152).dp, y = 1.dp)
                .background(color = colorResource(R.color.white))) {}
            Box(modifier = Modifier.size(width = 26.dp, height = 5.dp).offset(x = 152.dp, y = 1.dp)
                .background(color = colorResource(R.color.white))) {}}

        TypeList(onTypeClick = {navController.navigate(TypeScreen(id = it))})

        Box(modifier = Modifier.fillMaxWidth().background(color = colorResource(R.color.green2))
            .size(height = 70.dp, width = 0.dp)) {

            Image(
                painter = painterResource(id = R.drawable.img_1),
                contentDescription = "Custom Image Button",
                modifier = Modifier.size(50.dp).offset(x = 35.dp, y = 10.dp)
                    .clickable(onClick = {navController.navigate("MainView")}))

            Image(
                painter = painterResource(id = R.drawable.img_2),
                contentDescription = "Custom Image Button",
                modifier = Modifier.size(50.dp).offset(x = 180.dp, y = 10.dp)
                    .clickable(onClick = {navController.navigate("RecView")}))

            Image(
                painter = painterResource(id = R.drawable.img_3),
                contentDescription = "Custom Image Button",
                modifier = Modifier.size(50.dp).offset(x = 330.dp, y = 10.dp)
                    .clickable(onClick = {navController.navigate("InfoView")}))
        }
    }
}

@Serializable
data object TypeListScreen

@Serializable
data class TypeScreen(
    val id: Int
)

@Composable
fun TypeList(onTypeClick: (Int) -> Unit, modifier: Modifier = Modifier) {
    var typeList by remember {
        mutableStateOf<List<Type>>(emptyList())
    }

    LaunchedEffect(key1 = true) {
        getTypeListRealTime()
            .collect{ typeList = it }
    }

    LazyColumn(modifier = Modifier.height(774.dp), contentPadding = PaddingValues(
        horizontal = 42.dp, vertical = 32.dp),
        verticalArrangement = Arrangement.spacedBy(32.dp)) {
        items(typeList, key = { type -> type.id!! }) { type ->
            TypeCard(type = type, onClick = { type.id?.let { onTypeClick(it) } })
        }
    }
}

/* Для таблицы info */

@Composable
fun TypeDetails(navController: NavHostController, typeID: Int, modifier: Modifier = Modifier) {
    var type by remember { mutableStateOf<Type?>(null) }

    LaunchedEffect(Unit) {
        type = getTypeByID(typeID)
    }

    Column(modifier = Modifier.verticalScroll(ScrollState(0))) {
        Box(modifier = modifier.fillMaxWidth().height(240.dp)
                .clip(RoundedCornerShape(bottomEnd = 20.dp, bottomStart = 20.dp)),
            contentAlignment = Alignment.Center) {
            AsyncImage(model = type?.image, contentDescription = null,
                modifier = Modifier.fillMaxSize(), contentScale = ContentScale.Crop,)
        }

        Column(modifier = Modifier.padding(horizontal = 20.dp, vertical = 6.dp),
            verticalArrangement = Arrangement.spacedBy(6.dp)) {
            Text(text = type?.name ?: "", fontSize = 38.sp, fontFamily = font2)

            Spacer(modifier = Modifier.height(5.dp))

            Text(text = type?.description ?: "", fontSize = 24.sp, fontFamily = font3)

            Spacer(modifier = Modifier.height(15.dp))
        }

        Row {
            Button(onClick = { navController.navigate("RecView")},
            modifier = Modifier.size(width = 130.dp, height = 50.dp).offset(x = 20.dp)
                .border(3.dp, color = colorResource(R.color.green1), RoundedCornerShape(20.dp))
                .clip(RoundedCornerShape(20.dp)),
            colors = ButtonDefaults.buttonColors(containerColor = colorResource(R.color.green5))) {
            Text("Назад", fontSize = 22.sp, fontFamily = font3,
                fontWeight = FontWeight(900)) }
            Button(onClick = { navController.navigate("RecView")},
                modifier = Modifier.size(width = 130.dp, height = 50.dp).offset(x = 20.dp)
                    .border(3.dp, color = colorResource(R.color.green1), RoundedCornerShape(20.dp))
                    .clip(RoundedCornerShape(20.dp)),
                colors = ButtonDefaults.buttonColors(containerColor = colorResource(R.color.green5))) {
                Text("Удалить", fontSize = 22.sp, fontFamily = font3,
                    fontWeight = FontWeight(900)) } }

        Spacer(modifier = Modifier.height(15.dp))
    }
}

@Composable
fun TypeCard(type: Type, onClick: () -> Unit) {
    Box(modifier = Modifier.height(230.dp).fillMaxWidth()
        .clickable(onClick = onClick)
        .clip(RoundedCornerShape(20.dp))
        .verticalScroll(rememberScrollState()),
        contentAlignment = Alignment.Center) {
        AsyncImage(model = type.image, contentDescription = null,
            modifier = Modifier.fillMaxWidth().size(height = 230.dp, width = 0.dp))

        Box(modifier = Modifier.matchParentSize()
            .background(color = Color.Black.copy(alpha = 0.2f)))

        Text(text = type.name, fontSize = 32.sp, lineHeight = 5.sp,fontWeight = FontWeight(700),
            fontFamily = font2, color = Color.White, textAlign = TextAlign.Center)
    }

    Box(modifier = Modifier.size(width = 330.dp, height = 2.dp).offset(x = 0.dp, y = 16.dp)
        .background(color = colorResource(R.color.green3))) {}
}

@OptIn(SupabaseExperimental::class)
fun getTypeListRealTime() = //Получение листа информации в режиме реального времени
    supabaseClient.from("type")
        .selectAsFlow(Type::id)

suspend fun getTypeByID(id: Int) =
    supabaseClient.from("type")
        .select(columns = Columns.list("id", "name", "description", "image")) {
            filter {
                Type::id eq id
            }
        }
        .decodeSingle<Type>()

/* Для таблицы info */
