package com.example.greentown.dataView.operationView

import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.size
import androidx.compose.material3.Button
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.colorResource
import androidx.compose.ui.unit.dp
import androidx.navigation.NavHostController
import com.example.greentown.Model.Type
import com.example.greentown.Domain.Constants.supabaseClient
import com.example.greentown.R
import io.github.jan.supabase.postgrest.from
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext

@Composable
fun InsertView(navController: NavHostController) {
    var typeName by remember { mutableStateOf("") }
    var typeDescription by remember { mutableStateOf("") }
    var typeImage by remember { mutableStateOf("") }
    var showSuccessMessage by remember { mutableStateOf(false) }
    var showErrorMessage by remember { mutableStateOf("") }

    Column(modifier = Modifier.fillMaxSize(),
        horizontalAlignment = Alignment.CenterHorizontally) {
        OutlinedTextField(value = typeName, modifier = Modifier.size(width = 270.dp, height = 60.dp)
            .border(3.dp, color = colorResource(R.color.green1))
            .background(color = colorResource(R.color.white)), onValueChange = { typeName = it },
            label = { Text("Type Name") })

        OutlinedTextField(value = typeDescription, modifier = Modifier.size(width = 270.dp, height = 60.dp)
            .border(3.dp, color = colorResource(R.color.green1))
            .background(color = colorResource(R.color.white)), onValueChange = { typeDescription = it })

        OutlinedTextField(value = typeImage, modifier = Modifier.size(width = 270.dp, height = 60.dp)
            .border(3.dp, color = colorResource(R.color.green1))
            .background(color = colorResource(R.color.white)), onValueChange = { typeImage = it })

        Button(
            onClick = { val type = Type(name = typeName, description = typeDescription, image = typeImage)
            addType(type, onSuccess = { showSuccessMessage = true; typeName = ""; typeDescription = "" },
                onError = { showErrorMessage = it })
        }) {
            Text("Add Type")
        }
        if (showSuccessMessage) {
            Text("Product added successfully!", color = Color.Green)
        }
        if (showErrorMessage.isNotBlank()) {
            Text("Error: $showErrorMessage", color = Color.Red)
        }
    }
}

fun addType(type: Type, onSuccess: (Type) -> Unit, onError: (String) -> Unit) {
    CoroutineScope(Dispatchers.IO).launch {
        val response = supabaseClient.from("type").insert(type)
        withContext(Dispatchers.Main) {

        }
    }
}